EnvConfig class

Model to represent the configuration (trconfig.yaml).

Properties

androidDirPath → String
no setter
arbOutputDir ↔ String
getter/setter pair
dartFormatLineLength ↔ int
getter/setter pair
dartFtsUtilsPath → String
no setter
dartOutputDir ↔ String
getter/setter pair
dartOutputFtsUtils ↔ bool
getter/setter pair
dartTKeysClassname → String
no setter
dartTKeysId ↔ String
"outputDir + tkeys.dart"
getter/setter pair
dartTkeysPath → String
no setter
dartTranslationClassname → String
no setter
dartTranslationPath → String
no setter
dartTranslationsId ↔ String
getter/setter pair
entryFile ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasOutputArbDir → bool
no setter
hasOutputJsonDir → bool
no setter
inputVarsFile → String
no setter
inputYamlDir ↔ String
@deprecated assigned from entryFile
getter/setter pair
iosDirPath → String
no setter
jsonOutputDir ↔ String
getter/setter pair
locales ↔ List<String>
getter/setter pair
macosDirPath → String
no setter
masterLocale → String
no setter
outputAndroidLocales ↔ bool
getter/setter pair
outputArbTemplate ↔ String
getter/setter pair
outputJsonDir ↔ String
@deprecated
getter/setter pair
outputJsonTemplate ↔ String
getter/setter pair
paramFtsUtilsArgsPattern ↔ String
getter/setter pair
paramOutputPattern ↔ String
getter/setter pair
paramOutputPattern1 ↔ String
getter/setter pair
paramOutputPattern2 ↔ String
getter/setter pair
resolveLinkedKeys ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sheetCredentials ↔ dynamic
getter/setter pair
sheetId ↔ String?
getter/setter pair
tableId ↔ String?
getter/setter pair
useDartMaps ↔ bool
getter/setter pair
useIterativeCache ↔ bool
getter/setter pair
validTKeyFile → bool
no setter
validTranslationFile → bool
no setter

Methods

getArbFilePath(String locale) → String
getJsonFilePath(String locale) → String
isValidCredentials() → bool
isValidSheet() → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited